@@ -84,9 +84,8 @@ class Agent:
         sender_public_key: str,
     ) -> dict:
         task_id = message.get("data", {}).get("task_id", "unknown")
-        public_key_bytes = base64.b64decode(sender_public_key)
 
-        if not await self.identity.verify_message(message, public_key_bytes):
+        if not self.identity.verify_message(message, sender_public_key):
             return self._create_error_response(
                 task_id,
                 INVALID_SIGNATURE,
@@ -188,9 +187,6 @@ class Agent:
             return agent_info.keys.public_key
         return None
 
-    def identity(self) -> AgentIdentity:
-        return self.identity
-
     def endpoint(self) -> str:
         return self.config.endpoint
 
@@ -210,7 +206,7 @@ class Agent:
         if not target_agent.endpoint:
             raise AgentError(CONFIG_ERROR, f"Endpoint for agent {to_agent_id} not configured.")
 
-        task_request = await self.identity.createTaskRequest(
+        task_request = self.identity.createTaskRequest(
             to_agent_id,
             capability,
             params,
@@ -226,9 +222,8 @@ class Agent:
 
             response.raise_for_status()
             response_data = response.json()
-            public_key_bytes = base64.b64decode(target_agent.keys.public_key)
 
-            if not await self.identity.verify_message(response_data, public_key_bytes):
+            if not self.identity.verify_message(response_data, target_agent.keys.public_key):
                 raise AgentError(INVALID_SIGNATURE, "Response signature verification failed.")
 
             return response_data['data']
